# SISTEM
[Documentation](https://sistem.readthedocs.io/en/latest/) | [Installation](https://sistem.readthedocs.io/en/latest/install.html) | [Quickstart](https://sistem.readthedocs.io/en/latest/quickstart.html)

SISTEM (SImulation of Single-cell Tumor Evolution and Metastasis) is a software package and mathematical model for simulating tumor evolution,  cell migrations, and DNA-seq data at single-cell resolution. SISTEM simulates tumor populations under somatic clonal selection using an agent-based model. It can be used to simulate ground truth cell or clonal lineages and migration graphs while generating CNA profiles, SNV profiles, bulk-seq read counts, single-cell read counts, and allele-specific scDNA-seq reads. You can find the documentation and a number of examples by following the links appearing below the title. 

If you would like to learn more about the underlying algorithms used in SISTEM, please see our paper (yet to be posted).

SISTEM can be cited as follows:

SISTEM: simulation of tumor evolution, metastasis, and DNA-seq data under genotype-driven selection<br>
Samson Weiner and Mukul S. Bansal<br>
Under Review
